==> itoggle-7.x-1.1.tar.gz: itoggle/js/itoggle.js <==
Drupal.behaviors.itoggle = {
  attach: function(context, settings) {
    var $toggle = jQuery('div.itoggle-wrapper', context);
    
    if ($toggle.length) {
      $toggle.once(function(){
        var $t = jQuery(this),
        id = $t.attr('data-id'),
        type = $t.attr('data-type');

        $t.find('input').iToggle({
          keepLabel: false,
          easing: Drupal.settings.itoggle.easing,
          speed: Drupal.settings.itoggle.speed,
          onClick: function() {
            if (Drupal.settings.itoggle.onclick) {
              eval(Drupal.settings.itoggle.onclick);
            }
          },
          onClickOn: function() {
            if (Drupal.settings.itoggle.onclickon) {
              eval(Drupal.settings.itoggle.onclickon);
            }
          },
          onClickOff: function() {
            if (Drupal.settings.itoggle.onclickoff) {
              eval(Drupal.settings.itoggle.onclickoff);
            }
          },
          onSlide: function() {
            if (Drupal.settings.itoggle.onslide) {
              eval(Drupal.settings.itoggle.onslide);
            }
          },
          onSlideOn: function(){
            if (Drupal.settings.itoggle.onslideon) {
              eval(Drupal.settings.itoggle.onslideon);
            }
            jQuery.getJSON(Drupal.settings.basePath + 'js/itoggle/' + type + '/' + id + '/1', function(response){
              if (!response.ok || response.ok !== true) {
                jQuery('label.itoggle', $t).removeClass('iTon').addClass('iToff').removeAttr('style');
              }
            });
          },
          onSlideOff: function(){
            if (Drupal.settings.itoggle.onslideoff) {
              eval(Drupal.settings.itoggle.onslideoff);
            }

            jQuery.getJSON(Drupal.settings.basePath + 'js/itoggle/' + type + '/' + id + '/0', function(response){
              if (!response.ok || response.ok !== true) {
                jQuery('label.itoggle', $t).removeClass('iToff').addClass('iTon').removeAttr('style');
              }
            });
          }
        });
      });
    }
  }
};

==> itoggle-7.x-1.2.tar.gz: itoggle/js/itoggle.js <==
Drupal.behaviors.itoggle = {
  attach: function(context, settings) {
    var $toggle = jQuery('div.itoggle-wrapper', context);
    
    if ($toggle.length) {
      $toggle.once(function(){
        var $t = jQuery(this),
        id = $t.attr('data-id'),
        type = $t.attr('data-type'),
        token_key = 'itoggle_' + type + '_' + id + '_'; // we fill out the value later

        $t.find('input').iToggle({
          keepLabel: false,
          easing: Drupal.settings.itoggle.easing,
          speed: Drupal.settings.itoggle.speed,
          onClick: function() {
            if (Drupal.settings.itoggle.onclick) {
              eval(Drupal.settings.itoggle.onclick);
            }
          },
          onClickOn: function() {
            if (Drupal.settings.itoggle.onclickon) {
              eval(Drupal.settings.itoggle.onclickon);
            }
          },
          onClickOff: function() {
            if (Drupal.settings.itoggle.onclickoff) {
              eval(Drupal.settings.itoggle.onclickoff);
            }
          },
          onSlide: function() {
            if (Drupal.settings.itoggle.onslide) {
              eval(Drupal.settings.itoggle.onslide);
            }
          },
          onSlideOn: function(){
            if (Drupal.settings.itoggle.onslideon) {
              eval(Drupal.settings.itoggle.onslideon);
            }
            
            token_key += '1';
            var serial = 'token=' + Drupal.settings.itoggle.tokens[token_key];
            
            jQuery.post(Drupal.settings.basePath + 'js/itoggle/' + type + '/' + id + '/1', serial, function(response){
              if (!response.ok || response.ok !== true) {
                jQuery('label.itoggle', $t).removeClass('iTon').addClass('iToff').removeAttr('style');
              }
            }, 'json');
          },
          onSlideOff: function(){
            if (Drupal.settings.itoggle.onslideoff) {
              eval(Drupal.settings.itoggle.onslideoff);
            }

            token_key += '0';
            var serial = 'token=' + Drupal.settings.itoggle.tokens[token_key];

            jQuery.post(Drupal.settings.basePath + 'js/itoggle/' + type + '/' + id + '/0', serial, function(response){
              if (!response.ok || response.ok !== true) {
                jQuery('label.itoggle', $t).removeClass('iToff').addClass('iTon').removeAttr('style');
              }
            }, 'json');
          }
        });
      });
    }
  }
};
